# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.automation.v1 import action_pb2 as qwak_dot_automation_dot_v1_dot_action__pb2
from _qwak_proto.qwak.automation.v1 import trigger_pb2 as qwak_dot_automation_dot_v1_dot_trigger__pb2
from _qwak_proto.qwak.automation.v1 import notification_pb2 as qwak_dot_automation_dot_v1_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/automation/v1/automation.proto\x12\x12qwak.automation.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fqwak/automation/v1/action.proto\x1a qwak/automation/v1/trigger.proto\x1a%qwak/automation/v1/notification.proto\"\xcc\x01\n\nAutomation\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12;\n\x0f\x61utomation_spec\x18\x02 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\x12\x1b\n\x13qwak_environment_id\x18\x03 \x01(\t\x12\x39\n\x0c\x63reate_audit\x18\x04 \x01(\x0b\x32#.qwak.automation.v1.AutomationAudit\x12\x12\n\nis_deleted\x18\x05 \x01(\x08\"\xe3\x02\n\x0e\x41utomationSpec\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61utomation_name\x18\x03 \x01(\t\x12,\n\x07trigger\x18\x04 \x01(\x0b\x32\x1b.qwak.automation.v1.Trigger\x12*\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\x1a.qwak.automation.v1.Action\x12\x1e\n\x16\x61utomation_description\x18\x06 \x01(\t\x12\x12\n\nis_enabled\x18\x07 \x01(\x08\x12\x32\n\x08on_error\x18\x08 \x01(\x0b\x32 .qwak.automation.v1.Notification\x12\x34\n\non_success\x18\t \x01(\x0b\x32 .qwak.automation.v1.Notification\x12\x1b\n\x13\x65xecute_immediately\x18\n \x01(\x08\x12\x11\n\tis_sdk_v1\x18\x0b \x01(\x08\"L\n\x0f\x41utomationAudit\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x02 \x01(\tB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')



_AUTOMATION = DESCRIPTOR.message_types_by_name['Automation']
_AUTOMATIONSPEC = DESCRIPTOR.message_types_by_name['AutomationSpec']
_AUTOMATIONAUDIT = DESCRIPTOR.message_types_by_name['AutomationAudit']
Automation = _reflection.GeneratedProtocolMessageType('Automation', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATION,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.Automation)
  })
_sym_db.RegisterMessage(Automation)

AutomationSpec = _reflection.GeneratedProtocolMessageType('AutomationSpec', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONSPEC,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutomationSpec)
  })
_sym_db.RegisterMessage(AutomationSpec)

AutomationAudit = _reflection.GeneratedProtocolMessageType('AutomationAudit', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONAUDIT,
  '__module__' : 'qwak.automation.v1.automation_pb2'
  # @@protoc_insertion_point(class_scope:qwak.automation.v1.AutomationAudit)
  })
_sym_db.RegisterMessage(AutomationAudit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _AUTOMATION._serialized_start=199
  _AUTOMATION._serialized_end=403
  _AUTOMATIONSPEC._serialized_start=406
  _AUTOMATIONSPEC._serialized_end=761
  _AUTOMATIONAUDIT._serialized_start=763
  _AUTOMATIONAUDIT._serialized_end=839
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.ecosystem.v0.credentials_pb2
import qwak.ecosystem.v0.ecosystem_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AuthenticateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_PASSWORD_METHOD_FIELD_NUMBER: builtins.int
    QWAK_API_KEY_METHOD_FIELD_NUMBER: builtins.int
    @property
    def username_password_method(self) -> qwak.ecosystem.v0.ecosystem_pb2.UsernamePasswordMethod: ...
    @property
    def qwak_api_key_method(self) -> qwak.ecosystem.v0.ecosystem_pb2.QwakApiKeyMethod: ...
    def __init__(
        self,
        *,
        username_password_method: qwak.ecosystem.v0.ecosystem_pb2.UsernamePasswordMethod | None = ...,
        qwak_api_key_method: qwak.ecosystem.v0.ecosystem_pb2.QwakApiKeyMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_method", b"authentication_method", "qwak_api_key_method", b"qwak_api_key_method", "username_password_method", b"username_password_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_method", b"authentication_method", "qwak_api_key_method", b"qwak_api_key_method", "username_password_method", b"username_password_method"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["authentication_method", b"authentication_method"]) -> typing_extensions.Literal["username_password_method", "qwak_api_key_method"] | None: ...

global___AuthenticateRequest = AuthenticateRequest

class AuthenticateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    """The generated token"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The expiration time of the token"""
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "expired_at", b"expired_at"]) -> None: ...

global___AuthenticateResponse = AuthenticateResponse

class GetAuthenticatedUserContextRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAuthenticatedUserContextRequest = GetAuthenticatedUserContextRequest

class GetAuthenticatedUserContextResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATED_USER_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def authenticated_user_context(self) -> qwak.ecosystem.v0.ecosystem_pb2.AuthenticatedUserContext:
        """Accounts details"""
    def __init__(
        self,
        *,
        authenticated_user_context: qwak.ecosystem.v0.ecosystem_pb2.AuthenticatedUserContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authenticated_user_context", b"authenticated_user_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authenticated_user_context", b"authenticated_user_context"]) -> None: ...

global___GetAuthenticatedUserContextResponse = GetAuthenticatedUserContextResponse

class GetUnifiedUserContextRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """The user id to get context for"""
    account_id: builtins.str
    """The account id to get context for"""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "user_id", b"user_id"]) -> None: ...

global___GetUnifiedUserContextRequest = GetUnifiedUserContextRequest

class GetUnifiedUserContextResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def user_context(self) -> qwak.ecosystem.v0.ecosystem_pb2.AuthenticatedUserContext: ...
    def __init__(
        self,
        *,
        user_context: qwak.ecosystem.v0.ecosystem_pb2.AuthenticatedUserContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_context", b"user_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_context", b"user_context"]) -> None: ...

global___GetUnifiedUserContextResponse = GetUnifiedUserContextResponse

class GetAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The requested account id"""
    environment_id: builtins.str
    """The requested account id"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "environment_id", b"environment_id", "get_by", b"get_by"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "environment_id", b"environment_id", "get_by", b"get_by"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["get_by", b"get_by"]) -> typing_extensions.Literal["account_id", "environment_id"] | None: ...

global___GetAccountRequest = GetAccountRequest

class GetAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def account_details(self) -> qwak.ecosystem.v0.ecosystem_pb2.AccountDetails:
        """The account details"""
    def __init__(
        self,
        *,
        account_details: qwak.ecosystem.v0.ecosystem_pb2.AccountDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_details", b"account_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_details", b"account_details"]) -> None: ...

global___GetAccountResponse = GetAccountResponse

class ListUserAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListUserAccountsRequest = ListUserAccountsRequest

class ListUserAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNT_LIST_FIELD_NUMBER: builtins.int
    @property
    def user_account_list(self) -> qwak.ecosystem.v0.ecosystem_pb2.UserAccountList:
        """List of account for the authenticated user"""
    def __init__(
        self,
        *,
        user_account_list: qwak.ecosystem.v0.ecosystem_pb2.UserAccountList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_account_list", b"user_account_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_account_list", b"user_account_list"]) -> None: ...

global___ListUserAccountsResponse = ListUserAccountsResponse

class GetCloudCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def parameters(self) -> global___GetCloudCredentialsParameters: ...
    def __init__(
        self,
        *,
        parameters: global___GetCloudCredentialsParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters", b"parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters"]) -> None: ...

global___GetCloudCredentialsRequest = GetCloudCredentialsRequest

class GetCloudCredentialsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    PERMISSION_SET_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Requested duration for the credentials"""
    @property
    def permission_set(self) -> global___PermissionSet:
        """Permission set to include in the credentials"""
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        permission_set: global___PermissionSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration", "permission_set", b"permission_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "permission_set", b"permission_set"]) -> None: ...

global___GetCloudCredentialsParameters = GetCloudCredentialsParameters

class PermissionSet(google.protobuf.message.Message):
    """The requested predefined set of permissions the credentials will include"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EDGE_ENVIRONMENT_WORKLOAD_FIELD_NUMBER: builtins.int
    CORE_SERVICES_FIELD_NUMBER: builtins.int
    OFFLINE_FEATURE_STORE_CLIENT_FIELD_NUMBER: builtins.int
    REMOTE_BUILD_EXECUTOR_FIELD_NUMBER: builtins.int
    PULL_MODELS_CONTAINER_REGISTRY_FIELD_NUMBER: builtins.int
    BATCH_JOB_EXECUTOR_FIELD_NUMBER: builtins.int
    FEATURE_SET_PROCESSOR_FIELD_NUMBER: builtins.int
    ANALYTICS_SERVICE_FIELD_NUMBER: builtins.int
    @property
    def edge_environment_workload(self) -> global___EdgeEnvironmentWorkload:
        """Permission set for edge environments workload"""
    @property
    def core_services(self) -> global___CoreServices:
        """Permission set for core services needs credentials for environment"""
    @property
    def offline_feature_store_client(self) -> global___OfflineFeatureStoreClient:
        """Offline feature store client"""
    @property
    def remote_build_executor(self) -> global___RemoteBuildExecutor:
        """Remote build executor"""
    @property
    def pull_models_container_registry(self) -> global___PullModelsContainerRegistry:
        """Credentials for pull models from container registry"""
    @property
    def batch_job_executor(self) -> global___BatchJobExecutor:
        """Batch job executor"""
    @property
    def feature_set_processor(self) -> global___FeatureSetProcessor:
        """Batch job executor"""
    @property
    def analytics_service(self) -> global___AnalyticsService: ...
    def __init__(
        self,
        *,
        edge_environment_workload: global___EdgeEnvironmentWorkload | None = ...,
        core_services: global___CoreServices | None = ...,
        offline_feature_store_client: global___OfflineFeatureStoreClient | None = ...,
        remote_build_executor: global___RemoteBuildExecutor | None = ...,
        pull_models_container_registry: global___PullModelsContainerRegistry | None = ...,
        batch_job_executor: global___BatchJobExecutor | None = ...,
        feature_set_processor: global___FeatureSetProcessor | None = ...,
        analytics_service: global___AnalyticsService | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["analytics_service", b"analytics_service", "batch_job_executor", b"batch_job_executor", "core_services", b"core_services", "edge_environment_workload", b"edge_environment_workload", "feature_set_processor", b"feature_set_processor", "offline_feature_store_client", b"offline_feature_store_client", "pull_models_container_registry", b"pull_models_container_registry", "remote_build_executor", b"remote_build_executor", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_service", b"analytics_service", "batch_job_executor", b"batch_job_executor", "core_services", b"core_services", "edge_environment_workload", b"edge_environment_workload", "feature_set_processor", b"feature_set_processor", "offline_feature_store_client", b"offline_feature_store_client", "pull_models_container_registry", b"pull_models_container_registry", "remote_build_executor", b"remote_build_executor", "subject", b"subject"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["subject", b"subject"]) -> typing_extensions.Literal["edge_environment_workload", "core_services", "offline_feature_store_client", "remote_build_executor", "pull_models_container_registry", "batch_job_executor", "feature_set_processor", "analytics_service"] | None: ...

global___PermissionSet = PermissionSet

class EdgeEnvironmentWorkload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___EdgeEnvironmentWorkload = EdgeEnvironmentWorkload

class CoreServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___CoreServices = CoreServices

class OfflineFeatureStoreClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for (optional if environment chosen on headers)"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___OfflineFeatureStoreClient = OfflineFeatureStoreClient

class RemoteBuildExecutor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___RemoteBuildExecutor = RemoteBuildExecutor

class PullModelsContainerRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___PullModelsContainerRegistry = PullModelsContainerRegistry

class BatchJobExecutor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___BatchJobExecutor = BatchJobExecutor

class FeatureSetProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___FeatureSetProcessor = FeatureSetProcessor

class AnalyticsService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id the permission are for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___AnalyticsService = AnalyticsService

class GetCloudCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def cloud_credentials(self) -> qwak.ecosystem.v0.credentials_pb2.CloudCredentials:
        """The credentials of the environment in the cloud provider"""
    def __init__(
        self,
        *,
        cloud_credentials: qwak.ecosystem.v0.credentials_pb2.CloudCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> None: ...

global___GetCloudCredentialsResponse = GetCloudCredentialsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PagerdutyIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTED_PAGERDUTY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    ENDPOINT_URL_FIELD_NUMBER: builtins.int
    PAGERDUTY_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    @property
    def encrypted_pagerduty_auth_config(self) -> global___PagerdutyAuthConfig:
        """Encrypted Pagerduty auth configuration"""
    endpoint_url: builtins.str
    """Pagerduty endpoint url. Determined by the Api version"""
    @property
    def pagerduty_system_secret(self) -> global___PagerdutySystemSecretDescriptor:
        """Pagerduty system secret descriptor"""
    def __init__(
        self,
        *,
        encrypted_pagerduty_auth_config: global___PagerdutyAuthConfig | None = ...,
        endpoint_url: builtins.str = ...,
        pagerduty_system_secret: global___PagerdutySystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_pagerduty_auth_config", b"encrypted_pagerduty_auth_config", "pagerduty_system_secret", b"pagerduty_system_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_pagerduty_auth_config", b"encrypted_pagerduty_auth_config", "endpoint_url", b"endpoint_url", "pagerduty_system_secret", b"pagerduty_system_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["pagerduty_system_secret"] | None: ...

global___PagerdutyIntegration = PagerdutyIntegration

class PagerdutyIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGERDUTY_AUTH_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def pagerduty_auth_configuration(self) -> global___PagerdutyAuthConfig: ...
    def __init__(
        self,
        *,
        pagerduty_auth_configuration: global___PagerdutyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "pagerduty_auth_configuration", b"pagerduty_auth_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "pagerduty_auth_configuration", b"pagerduty_auth_configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["pagerduty_auth_configuration"] | None: ...

global___PagerdutyIntegrationSpec = PagerdutyIntegrationSpec

class PagerdutyAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_V1_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    EVENTS_V2_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def events_v1_auth_config(self) -> global___PagerdutyEventsV1AuthConfig:
        """Pagerduty events V1 Auth Config"""
    @property
    def events_v2_auth_config(self) -> global___PagerdutyEventsV2AuthConfig:
        """Pagerduty events V2 Auth Config"""
    def __init__(
        self,
        *,
        events_v1_auth_config: global___PagerdutyEventsV1AuthConfig | None = ...,
        events_v2_auth_config: global___PagerdutyEventsV2AuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "events_v1_auth_config", b"events_v1_auth_config", "events_v2_auth_config", b"events_v2_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "events_v1_auth_config", b"events_v1_auth_config", "events_v2_auth_config", b"events_v2_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["events_v1_auth_config", "events_v2_auth_config"] | None: ...

global___PagerdutyAuthConfig = PagerdutyAuthConfig

class PagerdutyEventsV1AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_KEY_FIELD_NUMBER: builtins.int
    service_key: builtins.str
    """Pagerduty service key"""
    def __init__(
        self,
        *,
        service_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_key", b"service_key"]) -> None: ...

global___PagerdutyEventsV1AuthConfig = PagerdutyEventsV1AuthConfig

class PagerdutyEventsV2AuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_KEY_FIELD_NUMBER: builtins.int
    routing_key: builtins.str
    """Pagerduty routing key"""
    def __init__(
        self,
        *,
        routing_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["routing_key", b"routing_key"]) -> None: ...

global___PagerdutyEventsV2AuthConfig = PagerdutyEventsV2AuthConfig

class PagerdutySystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    PAGERDUTY_EVENTS_V1_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    PAGERDUTY_EVENTS_V2_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """Pagerduty system secret name"""
    @property
    def pagerduty_events_v1_system_secret(self) -> global___PagerdutyEventsV1SystemSecretDescriptor:
        """Pagerduty v1 system secret descriptor"""
    @property
    def pagerduty_events_v2_system_secret(self) -> global___PagerdutyEventsV2SystemSecretDescriptor:
        """Pagerduty v2 system secret descriptor"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        pagerduty_events_v1_system_secret: global___PagerdutyEventsV1SystemSecretDescriptor | None = ...,
        pagerduty_events_v2_system_secret: global___PagerdutyEventsV2SystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagerduty_events_v1_system_secret", b"pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret", b"pagerduty_events_v2_system_secret", "pagerduty_secret", b"pagerduty_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagerduty_events_v1_system_secret", b"pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret", b"pagerduty_events_v2_system_secret", "pagerduty_secret", b"pagerduty_secret", "secret_name", b"secret_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["pagerduty_secret", b"pagerduty_secret"]) -> typing_extensions.Literal["pagerduty_events_v1_system_secret", "pagerduty_events_v2_system_secret"] | None: ...

global___PagerdutySystemSecretDescriptor = PagerdutySystemSecretDescriptor

class PagerdutyEventsV1SystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    service_key_secret_key: builtins.str
    """Pagerduty system secret service_key secret key"""
    def __init__(
        self,
        *,
        service_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_key_secret_key", b"service_key_secret_key"]) -> None: ...

global___PagerdutyEventsV1SystemSecretDescriptor = PagerdutyEventsV1SystemSecretDescriptor

class PagerdutyEventsV2SystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    routing_key_secret_key: builtins.str
    """Pagerduty system secret routing_key secret key"""
    def __init__(
        self,
        *,
        routing_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["routing_key_secret_key", b"routing_key_secret_key"]) -> None: ...

global___PagerdutyEventsV2SystemSecretDescriptor = PagerdutyEventsV2SystemSecretDescriptor

class PagerdutyValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGERDUTY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def pagerduty_auth_config(self) -> global___PagerdutyAuthConfig:
        """Pagerduty auth config"""
    def __init__(
        self,
        *,
        pagerduty_auth_config: global___PagerdutyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagerduty_auth_config", b"pagerduty_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagerduty_auth_config", b"pagerduty_auth_config"]) -> None: ...

global___PagerdutyValidationSpec = PagerdutyValidationSpec

class PagerdutyIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PagerdutyIntegrationOptions = PagerdutyIntegrationOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/streaming.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/feature_store/sources/streaming.proto\x12\x1aqwak.feature.store.sources\"\xc4\x01\n\x0fStreamingSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x0bkafkaSource\x18\x03 \x01(\x0b\x32\'.qwak.feature.store.sources.KafkaSourceB\x02\x18\x01H\x00\x12\x42\n\rkafkaSourceV1\x18\x04 \x01(\x0b\x32).qwak.feature.store.sources.KafkaSourceV1H\x00\x42\x06\n\x04type\"\x9f\x01\n\x0bKafkaSource\x12\x18\n\x10\x62ootstrap_server\x18\x01 \x01(\t\x12\x16\n\x0e\x63onsumer_topic\x18\x02 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x03 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x04 \x01(\t\x12\x1e\n\x16\x63onsumer_configuration\x18\x05 \x01(\t:\x02\x18\x01\"\xbd\x04\n\rKafkaSourceV1\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x10\n\x06\x61ssign\x18\x02 \x01(\tH\x00\x12\x13\n\tsubscribe\x18\x03 \x01(\tH\x00\x12\x1b\n\x11subscribe_pattern\x18\x04 \x01(\tH\x00\x12T\n\x0esecret_configs\x18\x07 \x03(\x0b\x32<.qwak.feature.store.sources.KafkaSourceV1.SecretConfigsEntry\x12^\n\x13passthrough_configs\x18\x08 \x03(\x0b\x32\x41.qwak.feature.store.sources.KafkaSourceV1.PassthroughConfigsEntry\x12\x44\n\x0f\x64\x65serialization\x18\t \x01(\x0b\x32+.qwak.feature.store.sources.Deserialization\x12I\n\x15\x61uthentication_method\x18\n \x01(\x0b\x32*.qwak.feature.store.sources.Authentication\x1a\x34\n\x12SecretConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17PassthroughConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x15\n\x13topic_configuration\"\xd8\x01\n\x0e\x41uthentication\x12>\n\x12sasl_configuration\x18\x01 \x01(\x0b\x32 .qwak.feature.store.sources.SaslH\x00\x12@\n\x13plain_configuration\x18\x02 \x01(\x0b\x32!.qwak.feature.store.sources.PlainH\x00\x12<\n\x11ssl_configuration\x18\x03 \x01(\x0b\x32\x1f.qwak.feature.store.sources.SslH\x00\x42\x06\n\x04type\"\x05\n\x03Ssl\"\x07\n\x05Plain\"\xc4\x01\n\x04Sasl\x12\x17\n\x0fusername_secret\x18\x01 \x01(\t\x12\x17\n\x0fpassword_secret\x18\x02 \x01(\t\x12\x41\n\x0esasl_mechanism\x18\x03 \x01(\x0e\x32).qwak.feature.store.sources.SaslMechanism\x12G\n\x11security_protocol\x18\x04 \x01(\x0e\x32,.qwak.feature.store.sources.SecurityProtocol\"\xb9\x01\n\x0f\x44\x65serialization\x12M\n\x13\x63ustom_deserializer\x18\x01 \x01(\x0b\x32..qwak.feature.store.sources.CustomDeserializerH\x00\x12O\n\x14generic_deserializer\x18\x02 \x01(\x0b\x32/.qwak.feature.store.sources.GenericDeserializerH\x00\x42\x06\n\x04type\"B\n\x12\x43ustomDeserializer\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x15\n\rartifact_path\x18\x02 \x01(\t\"m\n\x13GenericDeserializer\x12\x46\n\x13\x64\x65serializer_format\x18\x01 \x01(\x0e\x32).qwak.feature.store.sources.MessageFormat\x12\x0e\n\x06schema\x18\x02 \x01(\t*<\n\rSaslMechanism\x12\x0f\n\x0bSCRAMSHA256\x10\x00\x12\x0f\n\x0bSCRAMSHA512\x10\x01\x12\t\n\x05PLAIN\x10\x02* \n\x10SecurityProtocol\x12\x0c\n\x08SASL_SSL\x10\x00*0\n\rMessageFormat\x12\x0b\n\x07INVALID\x10\x00\x12\x08\n\x04JSON\x10\x01\x12\x08\n\x04\x41VRO\x10\x02\x42X\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_SASLMECHANISM = DESCRIPTOR.enum_types_by_name['SaslMechanism']
SaslMechanism = enum_type_wrapper.EnumTypeWrapper(_SASLMECHANISM)
_SECURITYPROTOCOL = DESCRIPTOR.enum_types_by_name['SecurityProtocol']
SecurityProtocol = enum_type_wrapper.EnumTypeWrapper(_SECURITYPROTOCOL)
_MESSAGEFORMAT = DESCRIPTOR.enum_types_by_name['MessageFormat']
MessageFormat = enum_type_wrapper.EnumTypeWrapper(_MESSAGEFORMAT)
SCRAMSHA256 = 0
SCRAMSHA512 = 1
PLAIN = 2
SASL_SSL = 0
INVALID = 0
JSON = 1
AVRO = 2


_STREAMINGSOURCE = DESCRIPTOR.message_types_by_name['StreamingSource']
_KAFKASOURCE = DESCRIPTOR.message_types_by_name['KafkaSource']
_KAFKASOURCEV1 = DESCRIPTOR.message_types_by_name['KafkaSourceV1']
_KAFKASOURCEV1_SECRETCONFIGSENTRY = _KAFKASOURCEV1.nested_types_by_name['SecretConfigsEntry']
_KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY = _KAFKASOURCEV1.nested_types_by_name['PassthroughConfigsEntry']
_AUTHENTICATION = DESCRIPTOR.message_types_by_name['Authentication']
_SSL = DESCRIPTOR.message_types_by_name['Ssl']
_PLAIN = DESCRIPTOR.message_types_by_name['Plain']
_SASL = DESCRIPTOR.message_types_by_name['Sasl']
_DESERIALIZATION = DESCRIPTOR.message_types_by_name['Deserialization']
_CUSTOMDESERIALIZER = DESCRIPTOR.message_types_by_name['CustomDeserializer']
_GENERICDESERIALIZER = DESCRIPTOR.message_types_by_name['GenericDeserializer']
StreamingSource = _reflection.GeneratedProtocolMessageType('StreamingSource', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGSOURCE,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.StreamingSource)
  })
_sym_db.RegisterMessage(StreamingSource)

KafkaSource = _reflection.GeneratedProtocolMessageType('KafkaSource', (_message.Message,), {
  'DESCRIPTOR' : _KAFKASOURCE,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.KafkaSource)
  })
_sym_db.RegisterMessage(KafkaSource)

KafkaSourceV1 = _reflection.GeneratedProtocolMessageType('KafkaSourceV1', (_message.Message,), {

  'SecretConfigsEntry' : _reflection.GeneratedProtocolMessageType('SecretConfigsEntry', (_message.Message,), {
    'DESCRIPTOR' : _KAFKASOURCEV1_SECRETCONFIGSENTRY,
    '__module__' : 'qwak.feature_store.sources.streaming_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.KafkaSourceV1.SecretConfigsEntry)
    })
  ,

  'PassthroughConfigsEntry' : _reflection.GeneratedProtocolMessageType('PassthroughConfigsEntry', (_message.Message,), {
    'DESCRIPTOR' : _KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY,
    '__module__' : 'qwak.feature_store.sources.streaming_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.KafkaSourceV1.PassthroughConfigsEntry)
    })
  ,
  'DESCRIPTOR' : _KAFKASOURCEV1,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.KafkaSourceV1)
  })
_sym_db.RegisterMessage(KafkaSourceV1)
_sym_db.RegisterMessage(KafkaSourceV1.SecretConfigsEntry)
_sym_db.RegisterMessage(KafkaSourceV1.PassthroughConfigsEntry)

Authentication = _reflection.GeneratedProtocolMessageType('Authentication', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATION,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.Authentication)
  })
_sym_db.RegisterMessage(Authentication)

Ssl = _reflection.GeneratedProtocolMessageType('Ssl', (_message.Message,), {
  'DESCRIPTOR' : _SSL,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.Ssl)
  })
_sym_db.RegisterMessage(Ssl)

Plain = _reflection.GeneratedProtocolMessageType('Plain', (_message.Message,), {
  'DESCRIPTOR' : _PLAIN,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.Plain)
  })
_sym_db.RegisterMessage(Plain)

Sasl = _reflection.GeneratedProtocolMessageType('Sasl', (_message.Message,), {
  'DESCRIPTOR' : _SASL,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.Sasl)
  })
_sym_db.RegisterMessage(Sasl)

Deserialization = _reflection.GeneratedProtocolMessageType('Deserialization', (_message.Message,), {
  'DESCRIPTOR' : _DESERIALIZATION,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.Deserialization)
  })
_sym_db.RegisterMessage(Deserialization)

CustomDeserializer = _reflection.GeneratedProtocolMessageType('CustomDeserializer', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMDESERIALIZER,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CustomDeserializer)
  })
_sym_db.RegisterMessage(CustomDeserializer)

GenericDeserializer = _reflection.GeneratedProtocolMessageType('GenericDeserializer', (_message.Message,), {
  'DESCRIPTOR' : _GENERICDESERIALIZER,
  '__module__' : 'qwak.feature_store.sources.streaming_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GenericDeserializer)
  })
_sym_db.RegisterMessage(GenericDeserializer)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _STREAMINGSOURCE.fields_by_name['kafkaSource']._options = None
  _STREAMINGSOURCE.fields_by_name['kafkaSource']._serialized_options = b'\030\001'
  _KAFKASOURCE._options = None
  _KAFKASOURCE._serialized_options = b'\030\001'
  _KAFKASOURCEV1_SECRETCONFIGSENTRY._options = None
  _KAFKASOURCEV1_SECRETCONFIGSENTRY._serialized_options = b'8\001'
  _KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY._options = None
  _KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY._serialized_options = b'8\001'
  _SASLMECHANISM._serialized_start=1812
  _SASLMECHANISM._serialized_end=1872
  _SECURITYPROTOCOL._serialized_start=1874
  _SECURITYPROTOCOL._serialized_end=1906
  _MESSAGEFORMAT._serialized_start=1908
  _MESSAGEFORMAT._serialized_end=1956
  _STREAMINGSOURCE._serialized_start=75
  _STREAMINGSOURCE._serialized_end=271
  _KAFKASOURCE._serialized_start=274
  _KAFKASOURCE._serialized_end=433
  _KAFKASOURCEV1._serialized_start=436
  _KAFKASOURCEV1._serialized_end=1009
  _KAFKASOURCEV1_SECRETCONFIGSENTRY._serialized_start=875
  _KAFKASOURCEV1_SECRETCONFIGSENTRY._serialized_end=927
  _KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY._serialized_start=929
  _KAFKASOURCEV1_PASSTHROUGHCONFIGSENTRY._serialized_end=986
  _AUTHENTICATION._serialized_start=1012
  _AUTHENTICATION._serialized_end=1228
  _SSL._serialized_start=1230
  _SSL._serialized_end=1235
  _PLAIN._serialized_start=1237
  _PLAIN._serialized_end=1244
  _SASL._serialized_start=1247
  _SASL._serialized_end=1443
  _DESERIALIZATION._serialized_start=1446
  _DESERIALIZATION._serialized_end=1631
  _CUSTOMDESERIALIZER._serialized_start=1633
  _CUSTOMDESERIALIZER._serialized_end=1699
  _GENERICDESERIALIZER._serialized_start=1701
  _GENERICDESERIALIZER._serialized_end=1810
# @@protoc_insertion_point(module_scope)



import os
import re
from typing import Optional

import requests

from _qwak_proto.qwak.builds.builds_orchestrator_service_pb2 import AuthenticationDetail
from qwak.clients.model_management.client import ModelsManagementClient
from qwak.exceptions import QwakException

TAG_REGEX = re.compile(r"^[a-zA-Z0-9_-]+$")


def validate_tag(tag: str) -> bool:
    """
    Check if tag exists.

    Args:
        tag: tag to check

    Returns: If tag is valid
    """
    return re.match(TAG_REGEX, tag) is not None


def fetch_model_id() -> Optional[str]:
    """
    Get model id from environment.

    Returns: model id if found.

    Notes:
        1. Checking if called inside a model - then model id saved as environment variable.
    """
    # Checking if called inside a model - then model id saved as environment variable
    return os.getenv("QWAK_MODEL_ID", None)


def validate_model(model_id: str) -> str:
    """
    Validate a model ID validity and existence
    """
    if not model_id:
        model_id = fetch_model_id()
        if not model_id:
            raise QwakException("Failed to determined model ID.")

    try:
        ModelsManagementClient().get_model(model_id=model_id)
    except Exception:
        raise QwakException("Failed to find model.")

    return model_id


def fetch_build_id() -> Optional[str]:
    """
    Get Build id from environment

    Returns: Build id if found

    Notes:
        1. Checking if called inside a model - then build id saved as environment variable.
    """
    # Checking if called inside a model - then model id saved as environment variable
    return os.getenv("QWAK_BUILD_ID", None)


def upload_data(
    upload_url: str,
    data: bytes,
    authentication_details: Optional[AuthenticationDetail],
    content_type: str = "text/plain",
) -> None:
    """
    Upload data
    Args:
        upload_url: the url to upload to.
        data: the data to upload
        authentication_details: authentication details for upload data
        content_type: Uploaded content-type
    """
    try:
        auth = None
        if (
            authentication_details.WhichOneof("integration_type")
            == "jfrog_authentication_detail"
        ):
            auth = (
                authentication_details.jfrog_authentication_detail.username,
                authentication_details.jfrog_authentication_detail.token,
            )

        http_response = requests.put(  # nosec B113
            upload_url,
            data=data,
            headers={"content-type": content_type},
            auth=auth,
        )

        if http_response.status_code not in [200, 201]:
            raise QwakException(
                f"Failed to upload data. "
                f"Status: [{http_response.status_code}], "
                f"reason: [{http_response.reason}]"
            )
    except Exception as e:
        raise QwakException(f"Failed to upload data. Error is {e}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v1/features_operator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/features_operator/v1/features_operator.proto\x12\x19qwak.features_operator.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x02\n\x19ValidationSuccessResponse\x12\x0e\n\x06sample\x18\x01 \x01(\t\x12H\n\x12\x63olumn_description\x18\x02 \x03(\x0b\x32,.qwak.features_operator.v1.ColumnDescription\x12U\n\x19pandas_column_description\x18\x03 \x03(\x0b\x32\x32.qwak.features_operator.v1.PandasColumnDescription\x12S\n\x18spark_column_description\x18\x04 \x03(\x0b\x32\x31.qwak.features_operator.v1.SparkColumnDescription\"<\n\x11\x43olumnDescription\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x12\n\nspark_type\x18\x02 \x01(\t\"C\n\x17PandasColumnDescription\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x13\n\x0bpandas_type\x18\x02 \x01(\t\"A\n\x16SparkColumnDescription\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x12\n\nspark_type\x18\x02 \x01(\t\"V\n\x19ValidationFailureResponse\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\tB(\n$com.qwak.ai.features.operator.api.v1P\x01\x62\x06proto3')



_VALIDATIONSUCCESSRESPONSE = DESCRIPTOR.message_types_by_name['ValidationSuccessResponse']
_COLUMNDESCRIPTION = DESCRIPTOR.message_types_by_name['ColumnDescription']
_PANDASCOLUMNDESCRIPTION = DESCRIPTOR.message_types_by_name['PandasColumnDescription']
_SPARKCOLUMNDESCRIPTION = DESCRIPTOR.message_types_by_name['SparkColumnDescription']
_VALIDATIONFAILURERESPONSE = DESCRIPTOR.message_types_by_name['ValidationFailureResponse']
ValidationSuccessResponse = _reflection.GeneratedProtocolMessageType('ValidationSuccessResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATIONSUCCESSRESPONSE,
  '__module__' : 'qwak.features_operator.v1.features_operator_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v1.ValidationSuccessResponse)
  })
_sym_db.RegisterMessage(ValidationSuccessResponse)

ColumnDescription = _reflection.GeneratedProtocolMessageType('ColumnDescription', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNDESCRIPTION,
  '__module__' : 'qwak.features_operator.v1.features_operator_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v1.ColumnDescription)
  })
_sym_db.RegisterMessage(ColumnDescription)

PandasColumnDescription = _reflection.GeneratedProtocolMessageType('PandasColumnDescription', (_message.Message,), {
  'DESCRIPTOR' : _PANDASCOLUMNDESCRIPTION,
  '__module__' : 'qwak.features_operator.v1.features_operator_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v1.PandasColumnDescription)
  })
_sym_db.RegisterMessage(PandasColumnDescription)

SparkColumnDescription = _reflection.GeneratedProtocolMessageType('SparkColumnDescription', (_message.Message,), {
  'DESCRIPTOR' : _SPARKCOLUMNDESCRIPTION,
  '__module__' : 'qwak.features_operator.v1.features_operator_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v1.SparkColumnDescription)
  })
_sym_db.RegisterMessage(SparkColumnDescription)

ValidationFailureResponse = _reflection.GeneratedProtocolMessageType('ValidationFailureResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATIONFAILURERESPONSE,
  '__module__' : 'qwak.features_operator.v1.features_operator_pb2'
  # @@protoc_insertion_point(class_scope:qwak.features_operator.v1.ValidationFailureResponse)
  })
_sym_db.RegisterMessage(ValidationFailureResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v1P\001'
  _VALIDATIONSUCCESSRESPONSE._serialized_start=114
  _VALIDATIONSUCCESSRESPONSE._serialized_end=403
  _COLUMNDESCRIPTION._serialized_start=405
  _COLUMNDESCRIPTION._serialized_end=465
  _PANDASCOLUMNDESCRIPTION._serialized_start=467
  _PANDASCOLUMNDESCRIPTION._serialized_end=534
  _SPARKCOLUMNDESCRIPTION._serialized_start=536
  _SPARKCOLUMNDESCRIPTION._serialized_end=601
  _VALIDATIONFAILURERESPONSE._serialized_start=603
  _VALIDATIONFAILURERESPONSE._serialized_end=689
# @@protoc_insertion_point(module_scope)



from typing import Dict, Tuple

import grpc
from _qwak_proto.qwak.admiral.secret.v0.secret_pb2 import (
    EnvironmentSecretIdentifier,
    SetSystemEnvironmentSecretOptions,
    SystemSecretDefinition,
)
from _qwak_proto.qwak.admiral.secret.v0.system_secret_service_pb2 import (
    DeleteSystemSecretRequest,
    DeleteSystemSecretResponse,
    GetSystemSecretRequest,
    GetSystemSecretResponse,
    SetSystemSecretRequest,
    SetSystemSecretResponse,
)
from _qwak_proto.qwak.admiral.secret.v0.system_secret_service_pb2_grpc import (
    SystemSecretServiceServicer,
)


class SystemSecretServiceMock(SystemSecretServiceServicer):
    _secrets: Dict[Tuple[str, str], SystemSecretDefinition] = dict()

    def clear(self):
        self._secrets.clear()

    def SetSystemSecret(self, request: SetSystemSecretRequest, context):
        """Set a value for a secret"""

        options: SetSystemEnvironmentSecretOptions = request.options
        identifier: EnvironmentSecretIdentifier = options.identifier
        definition: SystemSecretDefinition = SystemSecretDefinition(
            identifier=identifier, spec=options.spec
        )

        self._secrets[(identifier.name, identifier.environment_id)] = definition
        return SetSystemSecretResponse()

    def DeleteSystemSecret(self, request: DeleteSystemSecretRequest, context):
        """Delete secret"""
        name: str = request.identifier.name
        env_id: str = request.identifier.environment_id

        if (name, env_id) in self._secrets:
            del self._secrets[(name, env_id)]

        return DeleteSystemSecretResponse()

    def GetSystemSecret(self, request: GetSystemSecretRequest, context):
        """Get secret"""
        name: str = request.identifier.name
        env_id: str = request.identifier.environment_id
        return GetSystemSecretResponse(secret_definition=self._secrets[(name, env_id)])



from typing import Dict, List, Optional, Set

import grpc
from _qwak_proto.qwak.ecosystem.v0.ecosystem_pb2 import (
    EnvironmentDetails,
    UserContextAccountDetails,
    UserContextEnvironmentDetails,
    AuthenticatedUserContext,
)
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2 import (
    GetAuthenticatedUserContextRequest,
    GetCloudCredentialsRequest,
    GetCloudCredentialsResponse,
)
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2_grpc import (
    QwakEcosystemRuntimeStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class QwakSuggestionException:
    pass


class EcosystemClient:
    """
    Used for interacting with Qwak's Ecosystem
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._ecosystem_service = QwakEcosystemRuntimeStub(grpc_channel)

    def get_cloud_credentials(
        self, request: GetCloudCredentialsRequest
    ) -> GetCloudCredentialsResponse:
        try:
            return self._ecosystem_service.GetCloudCredentials(request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get cloud credentials, error is {e.details()}"
            )

    def get_authenticated_user_context(self) -> AuthenticatedUserContext:
        try:
            return self._ecosystem_service.GetAuthenticatedUserContext(
                GetAuthenticatedUserContextRequest()
            ).authenticated_user_context

        except grpc.RpcError as e:
            raise QwakException(f"Failed to get user context, error is {e.details()}")

    def get_account_details(self) -> UserContextAccountDetails:
        return self.get_authenticated_user_context().user.account_details

    def translate_environments_names_to_ids(
        self,
        environments_names: List[str],
    ) -> List[str]:
        names_to_selected_environments = self.get_environments_names_to_details(
            environments_names
        )

        return [
            names_to_selected_environments[env_name].id
            for env_name in environments_names
        ]

    def get_environments_names_to_details(
        self,
        environments_names: List[str],
    ) -> Dict[str, UserContextEnvironmentDetails]:
        account_details = self.get_account_details()

        if not environments_names:
            environment = account_details.environment_by_id[
                account_details.default_environment_id
            ]
            return {environment.name: environment}

        environments_names_set = set(environments_names)

        selected_environments = self.get_envs_by_names(
            account_details, environments_names_set
        )
        if len(selected_environments) != len(environments_names):
            available_environments_names = set(
                self.get_available_envs_names(account_details)
            )
            missing_envs = environments_names_set - available_environments_names

            raise QwakException(
                message=f"The following environments were not found: {','.join(missing_envs)},"
                f" Available environments are: {','.join(available_environments_names)}",
            )

        return {env.name: env for env in selected_environments}

    def get_environments(self) -> Dict[str, UserContextEnvironmentDetails]:
        account = self.get_account_details()

        return account.environment_by_id

    def get_environment_configuration(
        self, environment_name: Optional[str] = None
    ) -> EnvironmentDetails:
        account_details = self.get_account_details()
        if environment_name:
            matching_envs = self.get_envs_by_names(account_details, {environment_name})
            if not matching_envs:
                available_environments_names = self.get_available_envs_names(
                    account_details
                )
                raise QwakException(
                    f"Environment with name {environment_name} was not found. Available "
                    f"environments are: {', '.join(available_environments_names)}"
                )
            return matching_envs[0].configuration

        else:
            return account_details.environment_by_id[
                account_details.default_environment_id
            ]

    def get_environment_model_api(self, environment_name: Optional[str] = None) -> str:
        return self.get_environment_configuration(environment_name).model_api_url

    @staticmethod
    def get_available_envs_names(
        account_details: UserContextAccountDetails,
    ) -> List[str]:
        available_environments_names = list(
            map(
                lambda env: env.name,
                dict(account_details.environment_by_id).values(),
            )
        )
        return available_environments_names

    @staticmethod
    def get_envs_by_names(
        account_details: UserContextAccountDetails, environment_names: Set[str]
    ) -> List[UserContextEnvironmentDetails]:
        matching_envs = list(
            filter(
                lambda env: env.name in environment_names,
                dict(account_details.environment_by_id).values(),
            )
        )
        return matching_envs



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.deployment import alert_service_pb2 as qwak_dot_deployment_dot_alert__service__pb2


class AlertManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAlertsConfiguration = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetAlertsConfiguration',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.FromString,
                )
        self.ApplyAlertsConfiguration = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/ApplyAlertsConfiguration',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.FromString,
                )
        self.GetNotificationChannelsList = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetNotificationChannelsList',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.FromString,
                )
        self.ApplyNotificationChannel = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/ApplyNotificationChannel',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.FromString,
                )
        self.DeleteNotificationChannel = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/DeleteNotificationChannel',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.FromString,
                )
        self.GetNotificationChannelDetailsList = channel.unary_unary(
                '/qwak.deployment.management.AlertManagementService/GetNotificationChannelDetailsList',
                request_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.FromString,
                )


class AlertManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAlertsConfiguration(self, request, context):
        """Get alerts for deployed model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyAlertsConfiguration(self, request, context):
        """Update configuration for alerts in deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotificationChannelsList(self, request, context):
        """Get The Notification Channels list
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyNotificationChannel(self, request, context):
        """Channels to add or update
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotificationChannel(self, request, context):
        """Delete notification channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotificationChannelDetailsList(self, request, context):
        """Get Full Details for channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAlertsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertsConfiguration,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.SerializeToString,
            ),
            'ApplyAlertsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyAlertsConfiguration,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.SerializeToString,
            ),
            'GetNotificationChannelsList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationChannelsList,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.SerializeToString,
            ),
            'ApplyNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyNotificationChannel,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.SerializeToString,
            ),
            'DeleteNotificationChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotificationChannel,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.SerializeToString,
            ),
            'GetNotificationChannelDetailsList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationChannelDetailsList,
                    request_deserializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.deployment.management.AlertManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAlertsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetAlertsConfiguration',
            qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetAlertsConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyAlertsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/ApplyAlertsConfiguration',
            qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.ApplyAlertsConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotificationChannelsList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetNotificationChannelsList',
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelsListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/ApplyNotificationChannel',
            qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.ApplyNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotificationChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/DeleteNotificationChannel',
            qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.DeleteNotificationChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotificationChannelDetailsList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.AlertManagementService/GetNotificationChannelDetailsList',
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListRequest.SerializeToString,
            qwak_dot_deployment_dot_alert__service__pb2.GetNotificationChannelDetailsListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AuthenticateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_PASSWORD_METHOD_FIELD_NUMBER: builtins.int
    QWAK_API_KEY_METHOD_FIELD_NUMBER: builtins.int
    @property
    def username_password_method(self) -> global___UsernamePasswordMethod: ...
    @property
    def qwak_api_key_method(self) -> global___QwakApiKeyMethod: ...
    def __init__(
        self,
        *,
        username_password_method: global___UsernamePasswordMethod | None = ...,
        qwak_api_key_method: global___QwakApiKeyMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_method", b"authentication_method", "qwak_api_key_method", b"qwak_api_key_method", "username_password_method", b"username_password_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_method", b"authentication_method", "qwak_api_key_method", b"qwak_api_key_method", "username_password_method", b"username_password_method"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["authentication_method", b"authentication_method"]) -> typing_extensions.Literal["username_password_method", "qwak_api_key_method"] | None: ...

global___AuthenticateRequest = AuthenticateRequest

class UsernamePasswordMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    username: builtins.str
    """Username"""
    password: builtins.str
    """Password"""
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "username", b"username"]) -> None: ...

global___UsernamePasswordMethod = UsernamePasswordMethod

class QwakApiKeyMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QWAK_API_KEY_FIELD_NUMBER: builtins.int
    qwak_api_key: builtins.str
    """API key"""
    def __init__(
        self,
        *,
        qwak_api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["qwak_api_key", b"qwak_api_key"]) -> None: ...

global___QwakApiKeyMethod = QwakApiKeyMethod

class AuthenticateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    """The generated token"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The expiration time of the token"""
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "expired_at", b"expired_at"]) -> None: ...

global___AuthenticateResponse = AuthenticateResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.sources import data_source_service_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2


class DataSourceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDataSource = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/CreateDataSource',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceResponse.FromString,
                )
        self.UpdateDataSource = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/UpdateDataSource',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceResponse.FromString,
                )
        self.DeleteDataSource = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/DeleteDataSource',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceResponse.FromString,
                )
        self.GetDataSourceById = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/GetDataSourceById',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdResponse.FromString,
                )
        self.GetDataSourceByName = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/GetDataSourceByName',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameResponse.FromString,
                )
        self.ListDataSources = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/ListDataSources',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesResponse.FromString,
                )
        self.CreateDataSourceUploadURL = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/CreateDataSourceUploadURL',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.FromString,
                )
        self.CreateDataSourceUploadURLV1 = channel.unary_unary(
                '/qwak.feature.store.sources.DataSourceService/CreateDataSourceUploadURLV1',
                request_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.FromString,
                )


class DataSourceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDataSource(self, request, context):
        """Create a new data source
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataSource(self, request, context):
        """Update an existing data source
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataSource(self, request, context):
        """Delete a data source from the registry
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSourceById(self, request, context):
        """Get a data source by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSourceByName(self, request, context):
        """Get a data source by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDataSources(self, request, context):
        """List all registered data sources
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataSourceUploadURL(self, request, context):
        """Create a url for uploading data source configuration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataSourceUploadURLV1(self, request, context):
        """Create a url for uploading data source configuration V1 - taking into account env id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataSource,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceResponse.SerializeToString,
            ),
            'UpdateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataSource,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceResponse.SerializeToString,
            ),
            'DeleteDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataSource,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceResponse.SerializeToString,
            ),
            'GetDataSourceById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceById,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdResponse.SerializeToString,
            ),
            'GetDataSourceByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceByName,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameResponse.SerializeToString,
            ),
            'ListDataSources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataSources,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesResponse.SerializeToString,
            ),
            'CreateDataSourceUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataSourceUploadURL,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.SerializeToString,
            ),
            'CreateDataSourceUploadURLV1': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataSourceUploadURLV1,
                    request_deserializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.sources.DataSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/CreateDataSource',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/UpdateDataSource',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.UpdateDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/DeleteDataSource',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.DeleteDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSourceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/GetDataSourceById',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSourceByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/GetDataSourceByName',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.GetDataSourceByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDataSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/ListDataSources',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.ListDataSourcesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataSourceUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/CreateDataSourceUploadURL',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataSourceUploadURLV1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.sources.DataSourceService/CreateDataSourceUploadURLV1',
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_sources_dot_data__source__service__pb2.CreateDataSourceUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_DEFINITION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    FEATURE_SETS_FIELD_NUMBER: builtins.int
    @property
    def entity_definition(self) -> global___EntityDefinition:
        """Complete domain definition of the data source"""
    @property
    def metadata(self) -> global___EntityMetadata:
        """System generated metadata of the entity"""
    @property
    def feature_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureSetBrief]:
        """Linked feature sets"""
    def __init__(
        self,
        *,
        entity_definition: global___EntityDefinition | None = ...,
        metadata: global___EntityMetadata | None = ...,
        feature_sets: collections.abc.Iterable[global___FeatureSetBrief] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_definition", b"entity_definition", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_definition", b"entity_definition", "feature_sets", b"feature_sets", "metadata", b"metadata"]) -> None: ...

global___Entity = Entity

class EntityDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    ENTITY_SPEC_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Assigned unique id"""
    @property
    def entity_spec(self) -> global___EntitySpec:
        """Specifications of an entity"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
        entity_spec: global___EntitySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id", "entity_spec", b"entity_spec"]) -> None: ...

global___EntityDefinition = EntityDefinition

class EntityMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the entity was created"""
    created_by: builtins.str
    """Created by"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modified"""
    last_modified_by: builtins.str
    """Last modified by"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by"]) -> None: ...

global___EntityMetadata = EntityMetadata

class EntitySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ValueType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ValueTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EntitySpec._ValueType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: EntitySpec._ValueType.ValueType  # 0
        """An invalid state ValueType, the default if unset"""
        STRING: EntitySpec._ValueType.ValueType  # 1
        """String"""
        INT: EntitySpec._ValueType.ValueType  # 2
        """Integer"""

    class ValueType(_ValueType, metaclass=_ValueTypeEnumTypeWrapper): ...
    INVALID: EntitySpec.ValueType.ValueType  # 0
    """An invalid state ValueType, the default if unset"""
    STRING: EntitySpec.ValueType.ValueType  # 1
    """String"""
    INT: EntitySpec.ValueType.ValueType  # 2
    """Integer"""

    NAME_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name - should be unique per partner id"""
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """All possible entity keys - on customers data sources"""
    description: builtins.str
    """Description"""
    value_type: global___EntitySpec.ValueType.ValueType
    """Value type (int, string etc)"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        value_type: global___EntitySpec.ValueType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "keys", b"keys", "name", b"name", "value_type", b"value_type"]) -> None: ...

global___EntitySpec = EntitySpec

class FeatureSetBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature set id"""
    feature_set_name: builtins.str
    """Feature set name"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id", "feature_set_name", b"feature_set_name"]) -> None: ...

global___FeatureSetBrief = FeatureSetBrief



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DoubleVector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELEMENT_FIELD_NUMBER: builtins.int
    @property
    def element(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        element: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["element", b"element"]) -> None: ...

global___DoubleVector = DoubleVector

class Property(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STRING_VAL_FIELD_NUMBER: builtins.int
    INT_VAL_FIELD_NUMBER: builtins.int
    BOOL_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_VAL_FIELD_NUMBER: builtins.int
    TIMESTAMP_VAL_FIELD_NUMBER: builtins.int
    IS_EMPTY_FIELD_NUMBER: builtins.int
    name: builtins.str
    string_val: builtins.str
    int_val: builtins.int
    """we treat all ints as 64 - no int/long distinction"""
    bool_val: builtins.bool
    double_val: builtins.float
    """not distinguishing double vs float"""
    @property
    def timestamp_val(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    is_empty: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        string_val: builtins.str = ...,
        int_val: builtins.int = ...,
        bool_val: builtins.bool = ...,
        double_val: builtins.float = ...,
        timestamp_val: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        is_empty: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bool_val", b"bool_val", "double_val", b"double_val", "int_val", b"int_val", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "value_type", b"value_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bool_val", b"bool_val", "double_val", b"double_val", "int_val", b"int_val", "is_empty", b"is_empty", "name", b"name", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "value_type", b"value_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value_type", b"value_type"]) -> typing_extensions.Literal["string_val", "int_val", "bool_val", "double_val", "timestamp_val"] | None: ...

global___Property = Property

class SearchResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VECTOR_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    DISTANCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def vector(self) -> global___DoubleVector: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Property]: ...
    distance: builtins.float
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        vector: global___DoubleVector | None = ...,
        properties: collections.abc.Iterable[global___Property] | None = ...,
        distance: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector", b"vector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distance", b"distance", "id", b"id", "properties", b"properties", "vector", b"vector"]) -> None: ...

global___SearchResult = SearchResult

class StoredVector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VECTOR_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    VECTOR_IDENTIFIER_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def vector(self) -> global___DoubleVector: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Property]: ...
    @property
    def vector_identifier(self) -> global___VectorIdentifier: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        vector: global___DoubleVector | None = ...,
        properties: collections.abc.Iterable[global___Property] | None = ...,
        vector_identifier: global___VectorIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vector", b"vector", "vector_identifier", b"vector_identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "properties", b"properties", "vector", b"vector", "vector_identifier", b"vector_identifier"]) -> None: ...

global___StoredVector = StoredVector

class VectorIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    vector_id: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        vector_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["optional_tenant", b"optional_tenant", "tenant_id", b"tenant_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["optional_tenant", b"optional_tenant", "tenant_id", b"tenant_id", "vector_id", b"vector_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_tenant", b"optional_tenant"]) -> typing_extensions.Literal["tenant_id"] | None: ...

global___VectorIdentifier = VectorIdentifier



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/batch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/execution/v1/batch.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x01\n\x0e\x42\x61tchIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12H\n\x0emanual_trigger\x18\x02 \x01(\x0b\x32..qwak.feature.store.execution.v1.ManualTriggerH\x00\x12N\n\x11scheduled_trigger\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.ScheduledTriggerH\x00\x42\x0e\n\x0ctrigger_type\"A\n\rManualTrigger\x12\x30\n\x0ctrigger_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"J\n\x10ScheduledTrigger\x12\x36\n\x12logical_batch_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')



_BATCHINGESTION = DESCRIPTOR.message_types_by_name['BatchIngestion']
_MANUALTRIGGER = DESCRIPTOR.message_types_by_name['ManualTrigger']
_SCHEDULEDTRIGGER = DESCRIPTOR.message_types_by_name['ScheduledTrigger']
BatchIngestion = _reflection.GeneratedProtocolMessageType('BatchIngestion', (_message.Message,), {
  'DESCRIPTOR' : _BATCHINGESTION,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.BatchIngestion)
  })
_sym_db.RegisterMessage(BatchIngestion)

ManualTrigger = _reflection.GeneratedProtocolMessageType('ManualTrigger', (_message.Message,), {
  'DESCRIPTOR' : _MANUALTRIGGER,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ManualTrigger)
  })
_sym_db.RegisterMessage(ManualTrigger)

ScheduledTrigger = _reflection.GeneratedProtocolMessageType('ScheduledTrigger', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTRIGGER,
  '__module__' : 'qwak.execution.v1.batch_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ScheduledTrigger)
  })
_sym_db.RegisterMessage(ScheduledTrigger)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _BATCHINGESTION._serialized_start=100
  _BATCHINGESTION._serialized_end=311
  _MANUALTRIGGER._serialized_start=313
  _MANUALTRIGGER._serialized_end=378
  _SCHEDULEDTRIGGER._serialized_start=380
  _SCHEDULEDTRIGGER._serialized_end=454
# @@protoc_insertion_point(module_scope)



from qwak.inner.singleton_meta import SingletonMeta


class QwakAnalyticsLogger(metaclass=SingletonMeta):
    """
    Base class for Qwak analytics logger
    """

    def log(self, log):
        """
        Log data to Qwak's data lake
        :param log: data to be persisted
        """
        pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    STREAMING_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    @property
    def batch_featureset_deletion(self) -> global___BatchFeaturesetDeletion: ...
    @property
    def streaming_featureset_deletion(self) -> global___StreamingFeaturesetDeletion: ...
    @property
    def streaming_aggregation_featureset_deletion(self) -> global___StreamingAggregationFeaturesetDeletion: ...
    def __init__(
        self,
        *,
        batch_featureset_deletion: global___BatchFeaturesetDeletion | None = ...,
        streaming_featureset_deletion: global___StreamingFeaturesetDeletion | None = ...,
        streaming_aggregation_featureset_deletion: global___StreamingAggregationFeaturesetDeletion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_featureset_deletion", b"batch_featureset_deletion", "deletion_type", b"deletion_type", "streaming_aggregation_featureset_deletion", b"streaming_aggregation_featureset_deletion", "streaming_featureset_deletion", b"streaming_featureset_deletion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_featureset_deletion", b"batch_featureset_deletion", "deletion_type", b"deletion_type", "streaming_aggregation_featureset_deletion", b"streaming_aggregation_featureset_deletion", "streaming_featureset_deletion", b"streaming_featureset_deletion"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["deletion_type", b"deletion_type"]) -> typing_extensions.Literal["batch_featureset_deletion", "streaming_featureset_deletion", "streaming_aggregation_featureset_deletion"] | None: ...

global___FeaturesetDeletion = FeaturesetDeletion

class BatchFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BatchFeaturesetDeletion = BatchFeaturesetDeletion

class StreamingFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingFeaturesetDeletion = StreamingFeaturesetDeletion

class StreamingAggregationFeaturesetDeletion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamingAggregationFeaturesetDeletion = StreamingAggregationFeaturesetDeletion



import uuid
from typing import Dict, Optional

import grpc
from _qwak_proto.qwak.feature_store.features.feature_set_pb2 import (
    DeployedModelInUseLink,
    FeatureSet,
    FeatureSetDefinition,
    FeaturesetInfo,
    FeatureSetList,
    FeatureSetMetadata,
    FeaturesetSchedulingState,
    FeatureSetSpec,
    FeatureStatus,
)
from _qwak_proto.qwak.feature_store.features.feature_set_service_pb2 import (
    DeleteFeatureSetResponse,
    DeleteFeaturesetVersionResponse,
    GetEnvToFeatureSetsMappingResponse,
    GetFeatureSetByNameResponse,
    GetFeaturesetSchedulingStateResponse,
    ListFeatureSetsResponse,
    ListFeaturesetVersionsByNameResponse,
    RegisterFeatureSetResponse,
    SetActiveFeaturesetVersionResponse,
    UpdateFeatureSetResponse,
)
from _qwak_proto.qwak.feature_store.features.feature_set_service_pb2_grpc import (
    FeatureSetServiceServicer,
)

CURRENT_ENV_NAME = "env_name"


class FeatureSetServiceMock(FeatureSetServiceServicer):
    def __init__(self):
        self._features_spec: Dict[str, FeatureSetSpec] = {}
        self._fs_next_versions: Dict[str, int] = {}
        self._fs_versions_by_name: Dict[str, Dict[int, FeatureSetDefinition]] = {}
        self._fs_definition_by_id: Dict[str, FeatureSetDefinition] = {}
        # this mapping is used to test the GetEnvToFeatureSetsMapping API. Note that the populated features sets may not be aligned with the self._features_spec featuresets
        self._env_to_features_spec = (
            {}
        )  # env_name -> {featureset_name -> featureset_definition}

    def reset_features(self):
        self._features_spec.clear()
        self._fs_next_versions.clear()
        self._fs_versions_by_name.clear()
        self._fs_definition_by_id.clear()
        self._env_to_features_spec.clear()

    def setup_empty_env(self, env_name):
        self._env_to_features_spec[env_name] = {}

    def register_featureset_to_env_to_features_map(
        self, env_name, featureset_spec: FeatureSetSpec
    ):
        fs_id = str(uuid.uuid4())
        self._env_to_features_spec[env_name] = self._env_to_features_spec.get(
            env_name, {}
        )
        feature_set_definition = FeatureSetDefinition(
            feature_set_id=fs_id,
            feature_set_spec=featureset_spec,
            status=FeatureStatus.VALID,
        )
        self._env_to_features_spec[env_name][
            featureset_spec.name
        ] = feature_set_definition

    def RegisterFeatureSet(self, request, context):
        fs_id = str(uuid.uuid4())
        curr_version = 1
        featureset_definition: FeatureSetDefinition = FeatureSetDefinition(
            feature_set_id=fs_id,
            feature_set_spec=request.feature_set_spec,
            featureset_version_number=curr_version,
            status=FeatureStatus.VALID,
        )
        self._features_spec[fs_id] = featureset_definition.feature_set_spec
        self._fs_definition_by_id[fs_id] = featureset_definition
        self._fs_versions_by_name[featureset_definition.feature_set_spec.name] = {
            curr_version: featureset_definition
        }
        self._fs_next_versions[featureset_definition.feature_set_spec.name] = (
            curr_version + 1
        )

        return RegisterFeatureSetResponse(
            feature_set=FeatureSet(feature_set_definition=featureset_definition)
        )

    def UpdateFeatureSet(self, request, context):
        fs_id: str = request.feature_set_id
        if fs_id in self._fs_definition_by_id:
            curr_version = self._fs_next_versions[request.feature_set_spec.name]
            featureset_definition: FeatureSetDefinition = FeatureSetDefinition(
                feature_set_id=fs_id,
                feature_set_spec=request.feature_set_spec,
                featureset_version_number=curr_version,
                status=FeatureStatus.VALID,
            )
            self._fs_definition_by_id[fs_id] = featureset_definition
            self._features_spec[fs_id] = featureset_definition.feature_set_spec
            self._fs_next_versions[featureset_definition.feature_set_spec.name] = (
                curr_version + 1
            )

            curr_versions = self._fs_versions_by_name[request.feature_set_spec.name]
            curr_versions[curr_version] = featureset_definition
            self._fs_versions_by_name[
                featureset_definition.feature_set_spec.name
            ] = curr_versions

            return UpdateFeatureSetResponse(
                feature_set=FeatureSet(feature_set_definition=featureset_definition)
            )

        context.set_details(f"Feature set ID {request.feature_set_id} doesn't exist'")
        context.set_code(grpc.StatusCode.NOT_FOUND)

    def DeleteFeatureSet(self, request, context):
        fs_definition: Optional[FeatureSetDefinition] = self._fs_definition_by_id.get(
            request.feature_set_id, None
        )
        if fs_definition:
            self._features_spec.pop(request.feature_set_id)
            self._fs_definition_by_id.pop(request.feature_set_id)
            self._fs_versions_by_name.pop(fs_definition.feature_set_spec.name)
            self._fs_next_versions.pop(fs_definition.feature_set_spec.name)
            return DeleteFeatureSetResponse()

        context.set_details(f"Feature set ID {request.feature_set_id} doesn't exist'")
        context.set_code(grpc.StatusCode.NOT_FOUND)

    def GetFeatureSetByName(self, request, context):
        feature_sets = [
            (fs_id, fs_definition)
            for (fs_id, fs_definition) in self._fs_definition_by_id.items()
            if fs_definition.feature_set_spec.name == request.feature_set_name
        ]
        if feature_sets:
            fs_id, fs_definition = feature_sets[0]
            return GetFeatureSetByNameResponse(
                feature_set=FeatureSet(
                    feature_set_definition=fs_definition,
                    metadata=FeatureSetMetadata(),
                    deployed_models_in_use_link=[DeployedModelInUseLink()],
                )
            )

        context.set_details(
            f"Feature set named {request.feature_set_name} doesn't exist'"
        )
        context.set_code(grpc.StatusCode.NOT_FOUND)

    def ListFeatureSets(self, request, context):
        return ListFeatureSetsResponse(
            feature_families=[
                FeatureSet(
                    feature_set_definition=fs_definition,
                    metadata=FeatureSetMetadata(),
                    deployed_models_in_use_link=[DeployedModelInUseLink()],
                )
                for fs_definition in self._fs_definition_by_id.values()
            ]
        )

    def GetFeaturesetSchedulingState(self, request, context):
        return GetFeaturesetSchedulingStateResponse(
            state=FeaturesetSchedulingState.SCHEDULING_STATE_ENABLED
        )

    def GetEnvToFeatureSetsMapping(self, request, context):
        env_to_featuresets_mapping = {}

        for env_name, featureset_df_dict in self._env_to_features_spec.items():
            env_to_featuresets_mapping[env_name] = FeatureSetList(
                feature_sets=[
                    FeatureSet(
                        feature_set_definition=fs_definition,
                        metadata=FeatureSetMetadata(),
                        deployed_models_in_use_link=[DeployedModelInUseLink()],
                    )
                    for fs_name, fs_definition in featureset_df_dict.items()
                ]
            )

        return GetEnvToFeatureSetsMappingResponse(
            env_to_feature_set_mapping=env_to_featuresets_mapping
        )

    def DeleteFeaturesetVersion(self, request, context):
        version_number = request.featureset_version_number
        version_definitions: Optional[
            Dict[int, FeatureSetDefinition]
        ] = self._fs_versions_by_name.get(request.featureset_name, None)
        if version_definitions:
            version_definition = version_definitions.get(version_number, None)
            if version_definition:
                if (
                    self._fs_definition_by_id[
                        version_definition.feature_set_id
                    ].featureset_version_number
                    != version_number
                ):
                    version_definitions.pop(version_number)
                    return DeleteFeaturesetVersionResponse()
                else:
                    context.set_details("Active version cant be deleted")
                    context.set_code(grpc.StatusCode.FAILED_PRECONDITION)
            else:
                context.set_details(
                    f"Version {version_number} not found for Feature set name {request.featureset_name}"
                )
                context.set_code(grpc.StatusCode.NOT_FOUND)
        else:
            context.set_details(
                f"Feature set name {request.featureset_name} doesn't exist'"
            )
            context.set_code(grpc.StatusCode.NOT_FOUND)

    def SetActiveFeaturesetVersion(self, request, context):
        version_definitions: Optional[
            Dict[int, FeatureSetDefinition]
        ] = self._fs_versions_by_name.get(request.featureset_name, None)
        if version_definitions:
            version_definition = version_definitions.get(
                request.featureset_version_number, None
            )
            if version_definition:
                self._fs_definition_by_id[
                    version_definition.feature_set_id
                ] = version_definition
                return SetActiveFeaturesetVersionResponse()
            else:
                context.set_details(
                    f"Version {request.featureset_version_number} not found for Feature set name {request.featureset_name}"
                )
                context.set_code(grpc.StatusCode.NOT_FOUND)
        else:
            context.set_details(
                f"Feature set name {request.featureset_name} doesn't exist'"
            )
            context.set_code(grpc.StatusCode.NOT_FOUND)

    def ListFeaturesetVersionsByName(self, request, context):
        versions: Optional[
            Dict[int, FeatureSetDefinition]
        ] = self._fs_versions_by_name.get(request.featureset_name, None)
        if versions:
            return ListFeaturesetVersionsByNameResponse(
                featuresets=[
                    FeaturesetInfo(
                        featureset_definition=feature_definition,
                        metadata=FeatureSetMetadata(),
                    )
                    for feature_definition in self._fs_versions_by_name[
                        request.featureset_name
                    ].values()
                ]
            )

        context.set_details(
            f"Feature set name {request.featureset_name} doesn't exist'"
        )
        context.set_code(grpc.StatusCode.NOT_FOUND)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/v1/common/source_code/source_code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:qwak/feature_store/v1/common/source_code/source_code.proto\x12(qwak.feature.store.v1.common.source_code\"`\n\x0eSourceCodeSpec\x12N\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32<.qwak.feature.store.v1.common.source_code.SourceCodeArtifact\"k\n\x12SourceCodeArtifact\x12M\n\x0czip_artifact\x18\x01 \x01(\x0b\x32\x35.qwak.feature.store.v1.common.source_code.ZipArtifactH\x00\x42\x06\n\x04type\".\n\x0bZipArtifact\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmain_file\x18\x02 \x01(\tB3\n/com.qwak.ai.feature.store.v1.common.source_codeP\x01\x62\x06proto3')



_SOURCECODESPEC = DESCRIPTOR.message_types_by_name['SourceCodeSpec']
_SOURCECODEARTIFACT = DESCRIPTOR.message_types_by_name['SourceCodeArtifact']
_ZIPARTIFACT = DESCRIPTOR.message_types_by_name['ZipArtifact']
SourceCodeSpec = _reflection.GeneratedProtocolMessageType('SourceCodeSpec', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECODESPEC,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.SourceCodeSpec)
  })
_sym_db.RegisterMessage(SourceCodeSpec)

SourceCodeArtifact = _reflection.GeneratedProtocolMessageType('SourceCodeArtifact', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECODEARTIFACT,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.SourceCodeArtifact)
  })
_sym_db.RegisterMessage(SourceCodeArtifact)

ZipArtifact = _reflection.GeneratedProtocolMessageType('ZipArtifact', (_message.Message,), {
  'DESCRIPTOR' : _ZIPARTIFACT,
  '__module__' : 'qwak.feature_store.v1.common.source_code.source_code_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.v1.common.source_code.ZipArtifact)
  })
_sym_db.RegisterMessage(ZipArtifact)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/com.qwak.ai.feature.store.v1.common.source_codeP\001'
  _SOURCECODESPEC._serialized_start=104
  _SOURCECODESPEC._serialized_end=200
  _SOURCECODEARTIFACT._serialized_start=202
  _SOURCECODEARTIFACT._serialized_end=309
  _ZIPARTIFACT._serialized_start=311
  _ZIPARTIFACT._serialized_end=357
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass, field

from _qwak_proto.qwak.feature_store.sources.data_source_attribute_pb2 import (
    DataSourceAttributes as ProtoDataSourceAttributes,
    DataSourceAttributes,
)
from qwak.feature_store._common.source_code_spec import SourceCodeSpec


@dataclass
class DataSourceAttributes:
    source_code_spec: SourceCodeSpec = field(default_factory=lambda: SourceCodeSpec())

    def _to_proto(self) -> ProtoDataSourceAttributes:
        return ProtoDataSourceAttributes(
            source_code_spec=self.source_code_spec._to_proto()
        )

    @classmethod
    def _from_proto(cls, proto: ProtoDataSourceAttributes) -> DataSourceAttributes:
        return cls(
            source_code_spec=SourceCodeSpec._from_proto(proto=proto.source_code_spec)
        )
